@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::RecordReader;
 #ABSTRACT: Koha biblio/authority records reader
-$Koha::Contrib::Tamil::RecordReader::VERSION = '0.048';
+$Koha::Contrib::Tamil::RecordReader::VERSION = '0.049';
 use Moose;
 
 with 'MooseX::RW::Reader';
@@ -82,7 +82,8 @@ sub BUILD {
 
     # Koha version => items extraction if >= 3.4
     my $version = C4::Context->preference('Version');
-    $self->itemsextraction( $version ge '3.04' );
+    $self->itemsextraction(
+        $version =~ /^3/ && $version ge '3.04' || $version =~ /^[0-9]{2}/ ? 1 : 0 );
 
     if ( $version ge '3.09' && $self->source =~ /biblio/i &&
          C4::Context->preference('IncludeSeeFromInSearches') )
@@ -283,7 +284,7 @@ Koha::Contrib::Tamil::RecordReader - Koha biblio/authority records reader
 
 =head1 VERSION
 
-version 0.048
+version 0.049
 
 =head1 SYNOPSYS
 
